# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.10.6~d3420d2',
    built_at='2024-09-16 12:27:47Z',
    sha='d3420d2752fd7ac579779419711e46df5563b20e',
    branch='HEAD',
    tag='v4.10.6',
)
